@@ -212,16 +212,11 @@ impl Ramp {
         let mut headers = header::HeaderMap::new();
         headers.append(header::ACCEPT, header::HeaderValue::from_static("application/json"));
 
-        let params = [
-            ("grant_type", "refresh_token"),
-            ("refresh_token", &self.refresh_token),
-            ("redirect_uri", &self.redirect_uri),
-            ("client_id", &self.client_id),
-            ("client_secret", &self.client_secret),
-        ];
+        let params = [("grant_type", "refresh_token"), ("refresh_token", &self.refresh_token), ("redirect_uri", &self.redirect_uri)];
+
         let client = reqwest::Client::new();
         let resp = client
-            .post(&format!("{}/token", ENDPOINT))
+            .post(TOKEN_ENDPOINT)
             .headers(headers)
             .form(&params)
             .basic_auth(&self.client_id, Some(&self.client_secret))
@@ -233,7 +228,6 @@ impl Ramp {
         let t: AccessToken = resp.json().await.unwrap();
 
         self.token = t.access_token.to_string();
-        self.refresh_token = t.refresh_token.to_string();
 
         Ok(t)
     }
